@@ -1,20 +1,10 @@
-from ocli import sub, Main, Base
-from .cli import decrypt, encrypt, keygen, pick
+from ocli import Base
 
 
-# @sub(
-#     {
-#         "decrypt": decrypt.Decrypt,
-#         "encrypt": encrypt.Encrypt,
-#         "keygen": keygen.KeyGen,
-#         "pick": pick.Pick,
-#     },
-#     help="select sub command",
-#     required=True,
-# )
-# class Top(Main):
 class Top(Base):
     def options(self, opt):
+        from .cli import decrypt, encrypt, keygen, pick
+
         super().options(
             opt.sub(
                 {
