@@ -1,4 +1,5 @@
 def encode(n):
+    # type: (int) -> Generator[int, None, None]
     while 1:
         w = n & 0x7F
         n >>= 7
@@ -10,10 +11,12 @@ def encode(n):
 
 
 def encode_stream(src, n):
+    # type: (IO, int) -> None
     src.write(bytes(encode(n)))
 
 
 def decode_stream(src):
+    # type: (IO) -> int
     """Read a varint from `src`"""
     b = src.read(1)
     if b:
@@ -30,8 +33,9 @@ def decode_stream(src):
         return -1
 
 
-def decode(bytes):
-    it = iter(bytes)
+def decode(blob):
+    # type: (bytes) -> Generator[int, None, None]
+    it = iter(blob)
     while 1:
         try:
             i = next(it)
@@ -45,3 +49,9 @@ def decode(bytes):
             i = next(it)
             shift += 7
         yield result
+
+
+from typing import TYPE_CHECKING
+
+if TYPE_CHECKING:
+    from typing import Generator, IO
